# svt-text
Shows SVT Text in a terminal

## Dependencies
* Python 3.6
* Requests

## Installation
Make a symlink from your path to svt_text.py

## Example Usage
svt-text 100

## Screenshots

![Page 100](/100.png?raw=true "Page 100")

![Page 202](/202.png?raw=true "Page 202")

![Page 401](/401.png?raw=true "Page 401")
